Learn R Programming

LightFitR (version 1.0.0)

helio.disco: Turn Heliospectra into disco lights

Description

Congratulations! You've found the easter egg function!

Usage

helio.disco(filename, format = c("csv", "json"))

Value

Disco schedule file for the heliospectra

Arguments

filename

Character. Filename to export to

format

Character. Which format to export to? csv or json. Use extensions '.csv' or '.txt'

Details

This writes a schedule for Heliospectra DYNA lights which randomly changes colour every second for a fun disco effect. The disco will last until the Heliospectra runs out of memory (150 events), so you can get 2 min 30s of disco out of your expensive lights... Enjoy!

Examples

Run this code
tempfile_name = tempfile(fileext='.txt')
helio.disco(tempfile_name, format='json')

Run the code above in your browser using DataLab